Class: ScopedStruct::MethodCarrier::BlankSlate
- Inherits:
-
Object
- Object
- ScopedStruct::MethodCarrier::BlankSlate
- Defined in:
- lib/scoped_struct.rb
Overview
Jim Weirich’s BlankSlate class from onestepback.org/index.cgi/Tech/Ruby/BlankSlate.rdoc We use a slightly modified version of it to figure out what methods were defined in the scope block